@@ -84,7 +84,7 @@ with requests.Session() as session:
             eventTime,
             message,
             json.dumps(tags),
-            json.dumps(vars(detail))
+            json.dumps(detail)
         ))
 
 
@@ -135,7 +135,7 @@ with requests.Session() as session:
             eventTime,
             message,
             json.dumps(tags),
-            json.dumps(vars(detail))
+            json.dumps(detail)
         ))
 
 
